@@ -16,6 +16,7 @@ ResultsElement <- R6::R6Class("ResultsElement",
         .clearWith=NA,
         .state=NA,
         .stale=FALSE,
+        .refs=list(),
         deep_clone=function(name, value) {
             value
         }),
@@ -27,21 +28,22 @@ ResultsElement <- R6::R6Class("ResultsElement",
         visible=function() private$.visibleValue,
         title=function() private$.titleValue,
         state=function() private$.state,
+        refs=function() private$.refs,
         path=function() {
-            if ("ResultsElement" %in% class(self$.parent))
+            if (inherits(self$.parent, "ResultsElement"))
                 return(paste(self$.parent$path, self$name, sep="/"))
             else
                 return(self$name)
         },
         root=function() {
             parent <- self
-            while ("ResultsElement" %in% class(parent))
+            while (inherits(parent, "ResultsElement"))
                 parent <- parent$.parent
             parent
         },
         analysis=function() {
             parent <- self$.parent
-            while ("ResultsElement" %in% class(parent))
+            while (inherits(parent, "ResultsElement"))
                 parent <- parent$.parent
             parent
         },
@@ -54,7 +56,8 @@ ResultsElement <- R6::R6Class("ResultsElement",
             name,
             title,
             visible,
-            clearWith) {
+            clearWith,
+            refs=list()) {
 
             private$.options <- options
             private$.name <- name
@@ -158,11 +161,7 @@ ResultsElement <- R6::R6Class("ResultsElement",
         },
         asProtoBuf=function(incAsText=FALSE, status=NULL) {
 
-            initProtoBuf()
-
-            if (is.null(private$.visibleExpr))
-                v <- jamovi.coms.Visible$DEFAULT_YES
-            else if (identical(private$.visibleExpr, 'TRUE'))
+            if (identical(private$.visibleExpr, 'TRUE'))
                 v <- jamovi.coms.Visible$YES
             else if (identical(private$.visibleExpr, 'FALSE'))
                 v <- jamovi.coms.Visible$NO
@@ -173,8 +172,8 @@ ResultsElement <- R6::R6Class("ResultsElement",
 
             if (private$.status == 'error')
                 s <- jamovi.coms.AnalysisStatus$ANALYSIS_ERROR
-            else if (self$isFilled())
-                s <- jamovi.coms.AnalysisStatus$ANALYSIS_COMPLETE
+            # else if (self$isFilled())  # this takes a surprising amount of time
+            #     s <- jamovi.coms.AnalysisStatus$ANALYSIS_COMPLETE
             else if (private$.status == 'running')
                 s <- jamovi.coms.AnalysisStatus$ANALYSIS_RUNNING
             else if (private$.status == 'inited')
@@ -207,7 +206,7 @@ ResultsElement <- R6::R6Class("ResultsElement",
                 state <- raw()
             }
 
-            element <- RProtoBuf::new(jamovi.coms.ResultsElement,
+            element <- RProtoBuf_new(jamovi.coms.ResultsElement,
                 name=private$.name,
                 title=self$title,
                 stale=private$.stale,
@@ -216,7 +215,7 @@ ResultsElement <- R6::R6Class("ResultsElement",
                 visible=v)
 
             if (private$.status == 'error') {
-                error <- RProtoBuf::new(jamovi.coms.Error,
+                error <- RProtoBuf_new(jamovi.coms.Error,
                                         message=private$.error)
                 element$error <- error
                 element$status <- jamovi.coms.AnalysisStatus$ANALYSIS_ERROR
@@ -224,7 +223,7 @@ ResultsElement <- R6::R6Class("ResultsElement",
 
             element
         },
-        fromProtoBuf=function(pb, oChanges=NULL, vChanges=NULL) {
+        fromProtoBuf=function(pb, oChanges, vChanges) {
 
             someChanges <- length(oChanges) > 0 || length(vChanges) > 0
             if (someChanges && base::identical('*', private$.clearWith))
